@@ -13,7 +13,9 @@
     "FransesB1"
     "FransesB2"
     "McL93"
-    "McLeod"
+    "Mcleod1993parsimony"
+    "McLeod1994diagnostic"
+    "McLeod1995diagnosticCorrection"
     "b:Luleo94"
     "b:Varna92"
     "Sophie2005pacf"
